@@ -39,13 +39,14 @@ mod youtube_options;
 // use super::super::super::player::Player;
 use super::{Activity, Context, ExitReason, Status};
 use crate::config::MUSIC_DIR;
-use crate::player::AudioPlayer;
 use crate::song::Song;
 use crate::ui::activity::tageditor::TagEditorActivity;
 use std::str::FromStr;
 // Ext
 use crate::config::TermusicConfig;
 use crate::invidious::YoutubeVideo;
+use crate::player::AudioPlayer;
+use crate::player::Player;
 use crossterm::terminal::{disable_raw_mode, enable_raw_mode};
 use log::error;
 use std::path::{Path, PathBuf};
@@ -59,7 +60,7 @@ use tuirealm::{Payload, Value, View};
 // -- components
 const COMPONENT_LABEL_HELP: &str = "LABEL_HELP";
 const COMPONENT_PARAGRAPH_LYRIC: &str = "PARAGRAPH_LYRIC";
-const COMPONENT_SCROLLTABLE: &str = "SCROLLTABLE";
+const COMPONENT_TABLE: &str = "SCROLLTABLE";
 const COMPONENT_SCROLLTABLE_YOUTUBE: &str = "SCROLLTABLE_YOUTUBE";
 const COMPONENT_TREEVIEW: &str = "TREEVIEW";
 const COMPONENT_PROGRESS: &str = "PROGRESS";
@@ -82,7 +83,7 @@ pub struct MainActivity {
     redraw: bool,
     path: PathBuf,
     tree: Tree,
-    player: AudioPlayer,
+    player: Player,
     queue_items: Vec<Song>,
     time_pos: i64,
     status: Option<Status>,
@@ -122,7 +123,7 @@ impl Default for MainActivity {
             redraw: true, // Draw at first `on_draw`
             tree: Tree::new(Self::dir_tree(p, 3)),
             path: p.to_path_buf(),
-            player: AudioPlayer::new(),
+            player: Player::default(),
             queue_items: vec![],
             time_pos: 0,
             status: None,
