@@ -24,7 +24,7 @@
 // locals
 use super::{
     MainActivity, Status, COMPONENT_CONFIRMATION_INPUT, COMPONENT_CONFIRMATION_RADIO,
-    COMPONENT_INPUT_URL, COMPONENT_PARAGRAPH_LYRIC, COMPONENT_PROGRESS, COMPONENT_SCROLLTABLE,
+    COMPONENT_INPUT_URL, COMPONENT_PARAGRAPH_LYRIC, COMPONENT_PROGRESS, COMPONENT_TABLE,
     COMPONENT_TEXT_ERROR, COMPONENT_TEXT_HELP, COMPONENT_TREEVIEW,
 };
 use crate::song::Song;
@@ -35,12 +35,14 @@ use humantime::format_duration;
 // use lrc::{Lyrics, TimeTag};
 use super::TransferState;
 use crate::invidious::InvidiousInstance;
+use crate::player::AudioPlayer;
 use std::path::{Path, PathBuf};
 use std::time::Duration;
+use tui_realm_stdlib::{label, paragraph, progress_bar};
 use tui_realm_treeview::TreeViewPropsBuilder;
-use tuirealm::components::{label, paragraph, progress_bar};
 use tuirealm::event::{Event, KeyCode, KeyEvent, KeyModifiers};
-use tuirealm::props::TextSpanBuilder;
+use tuirealm::props::TextSpan;
+use tuirealm::tui::layout::Alignment;
 use tuirealm::PropsBuilder;
 use tuirealm::{Msg, Payload, Value};
 
@@ -54,21 +56,21 @@ impl MainActivity {
         match ref_msg {
             None => None, // Exit after None
             Some(msg) => match msg {
-                (COMPONENT_TREEVIEW, &MSG_KEY_TAB) => {
-                    self.view.active(COMPONENT_SCROLLTABLE);
+                (COMPONENT_TREEVIEW,key) if key== &MSG_KEY_TAB => {
+                    self.view.active(COMPONENT_TABLE);
                     None
                 }
-                (COMPONENT_SCROLLTABLE, &MSG_KEY_TAB) => {
+                (COMPONENT_TABLE, key) if key== &MSG_KEY_TAB => {
                     self.view.active(COMPONENT_TREEVIEW);
                     None
                 }
                 // yank
-                (COMPONENT_TREEVIEW, &MSG_KEY_CHAR_Y) => {
+                (COMPONENT_TREEVIEW, key) if key== &MSG_KEY_CHAR_Y => {
                     self.yank();
                     None
                 }
                 // paste
-                (COMPONENT_TREEVIEW, &MSG_KEY_CHAR_P) => {
+                (COMPONENT_TREEVIEW, key) if key== &MSG_KEY_CHAR_P => {
                     if let Err(e) = self.paste(){
                         self.mount_error(e.to_string().as_ref());
                     }
@@ -83,12 +85,12 @@ impl MainActivity {
                         self.view.get_props(COMPONENT_TREEVIEW).unwrap(),
                     )
                     .with_tree(self.tree.root())
-                    .with_title(Some(String::from(self.path.to_string_lossy())))
+                    .with_title(String::from(self.path.to_string_lossy()),Alignment::Left)
                     .build();
                     let msg = self.view.update(COMPONENT_TREEVIEW, props);
                     self.update(msg)
                 }
-                (COMPONENT_TREEVIEW, &MSG_KEY_BACKSPACE) => {
+                (COMPONENT_TREEVIEW, key) if key== &MSG_KEY_BACKSPACE => {
                     // Update tree
                     match self.upper_dir() {
                         None => None,
@@ -100,7 +102,7 @@ impl MainActivity {
                                 self.view.get_props(COMPONENT_TREEVIEW).unwrap(),
                             )
                             .with_tree(self.tree.root())
-                            .with_title(Some(String::from(self.path.to_string_lossy())))
+                            .with_title(String::from(self.path.to_string_lossy()),Alignment::Left)
                             .build();
                             let msg = self.view.update(COMPONENT_TREEVIEW, props);
                             self.update(msg)
@@ -108,7 +110,7 @@ impl MainActivity {
                     }
                 }
                 // seek
-                (_, &MSG_KEY_CHAR_F) => match self.player.seek(5) {
+                (_, key) if key== &MSG_KEY_CHAR_F => match self.player.seek(5) {
                     Ok(_) =>{
                         self.time_pos += 5;
                         None
@@ -119,15 +121,18 @@ impl MainActivity {
                     },
                 },
                 // seek backward
-                (_, &MSG_KEY_CHAR_B) => match self.player.seek(-5) {
+                (_, key) if key== &MSG_KEY_CHAR_B => match self.player.seek(-5) {
                     Ok(_) => {
                         self.time_pos -= 5;
                         None
                     }
-                    Err(_) => None,
+                    Err(_) => {
+                        self.status = Some(Status::Stopped);
+                        None
+                    }
                 },
                 // adjust lyric delay 
-                (_, &MSG_KEY_CHAR_CAPITAL_F) => {
+                (_, key) if key== &MSG_KEY_CHAR_CAPITAL_F => {
                    if let Some(song) = self.current_song.as_mut(){
                    if let Some(lyric) = song.parsed_lyric.as_mut() {
                        lyric.adjust_offset(self.time_pos,1000);
@@ -142,7 +147,7 @@ impl MainActivity {
                 }
                 ,
                 // adjust lyric delay 
-                (_, &MSG_KEY_CHAR_CAPITAL_B) =>  {
+                (_, key) if key== &MSG_KEY_CHAR_CAPITAL_B =>  {
                     if let Some(song) = self.current_song.as_mut() {
                    if let Some(lyric) = song.parsed_lyric.as_mut() {
                        lyric.adjust_offset(self.time_pos,-1000);
@@ -159,7 +164,7 @@ impl MainActivity {
                 },
 
 
-                (COMPONENT_TREEVIEW, &MSG_KEY_CHAR_H) => {
+                (COMPONENT_TREEVIEW, key) if key== &MSG_KEY_CHAR_H => {
                     let event: Event = Event::Key(KeyEvent {
                         code: KeyCode::Left,
                         modifiers: KeyModifiers::NONE,
@@ -167,7 +172,7 @@ impl MainActivity {
                     self.view.on(event);
                     None
                 }
-                (COMPONENT_SCROLLTABLE, &MSG_KEY_CHAR_G) => {
+                (COMPONENT_TABLE, key) if key== &MSG_KEY_CHAR_G => {
                     let event: Event = Event::Key(KeyEvent {
                         code: KeyCode::Home,
                         modifiers: KeyModifiers::NONE,
@@ -176,7 +181,7 @@ impl MainActivity {
                     None
                 }
 
-                (COMPONENT_SCROLLTABLE, &MSG_KEY_CHAR_CAPITAL_G) => {
+                (COMPONENT_TABLE,key) if key==  &MSG_KEY_CHAR_CAPITAL_G => {
                     let event: Event = Event::Key(KeyEvent {
                         code: KeyCode::End,
                         modifiers: KeyModifiers::NONE,
@@ -185,7 +190,7 @@ impl MainActivity {
                     None
                 }
 
-                (_, &MSG_KEY_CHAR_J) => {
+                (_,key) if key==  &MSG_KEY_CHAR_J => {
                     let event: Event = Event::Key(KeyEvent {
                         code: KeyCode::Down,
                         modifiers: KeyModifiers::NONE,
@@ -193,7 +198,7 @@ impl MainActivity {
                     self.view.on(event);
                     None
                 }
-                (_, &MSG_KEY_CHAR_K) => {
+                (_,key) if key==  &MSG_KEY_CHAR_K => {
                     let event: Event = Event::Key(KeyEvent {
                         code: KeyCode::Up,
                         modifiers: KeyModifiers::NONE,
@@ -201,7 +206,7 @@ impl MainActivity {
                     self.view.on(event);
                     None
                 }
-                (COMPONENT_TREEVIEW, &MSG_KEY_CHAR_L) => {
+                (COMPONENT_TREEVIEW,key) if key==  &MSG_KEY_CHAR_L => {
                     // Add selected song to queue
                     match self.view.get_state(COMPONENT_TREEVIEW) {
                         Some(Payload::One(Value::Str(node_id))) => {
@@ -225,7 +230,7 @@ impl MainActivity {
                         _ => None,
                     }
                 }
-                (COMPONENT_TREEVIEW, &MSG_KEY_CHAR_CAPITAL_L) => {
+                (COMPONENT_TREEVIEW,key) if key==  &MSG_KEY_CHAR_CAPITAL_L => {
                     // Add all songs in a folder to queue
                     match self.view.get_state(COMPONENT_TREEVIEW) {
                         Some(Payload::One(Value::Str(node_id))) => {
@@ -246,8 +251,8 @@ impl MainActivity {
                     }
                 }
 
-                (COMPONENT_SCROLLTABLE, &MSG_KEY_CHAR_L) => {
-                    match self.view.get_state(COMPONENT_SCROLLTABLE) {
+                (COMPONENT_TABLE,key) if key==  &MSG_KEY_CHAR_L => {
+                    match self.view.get_state(COMPONENT_TABLE) {
                         Some(Payload::One(Value::Usize(index))) => {
                             self.time_pos = 0;
                             self.current_song = Some(self.queue_items[index].clone());
@@ -259,8 +264,8 @@ impl MainActivity {
                     }
                 }
 
-                (COMPONENT_SCROLLTABLE, &MSG_KEY_CHAR_D) => {
-                    match self.view.get_state(COMPONENT_SCROLLTABLE) {
+                (COMPONENT_TABLE,key) if key==  &MSG_KEY_CHAR_D => {
+                    match self.view.get_state(COMPONENT_TABLE) {
                         Some(Payload::One(Value::Usize(index))) => {
                             self.delete_item(index);
                             None
@@ -269,13 +274,13 @@ impl MainActivity {
                     }
                 }
 
-                (COMPONENT_SCROLLTABLE, &MSG_KEY_CHAR_CAPITAL_D) => {
+                (COMPONENT_TABLE,key) if key==  &MSG_KEY_CHAR_CAPITAL_D => {
                     self.empty_queue();
                     None
                 }
 
                 // Toggle pause
-                (_, &MSG_KEY_SPACE) => {
+                (_,key) if key==  &MSG_KEY_SPACE => {
                     if self.player.is_paused() {
                         self.status = Some(Status::Running);
                         self.player.resume();
@@ -286,23 +291,23 @@ impl MainActivity {
                     None
                 }
                 // Toggle skip
-                (_, &MSG_KEY_CHAR_N) => {
+                (_,key) if key==  &MSG_KEY_CHAR_N => {
                     self.status = Some(Status::Stopped);
                     None
                 }
                 // shuffle
-                (COMPONENT_SCROLLTABLE, &MSG_KEY_CHAR_S) => {
+                (COMPONENT_TABLE,key) if key==  &MSG_KEY_CHAR_S => {
                     self.shuffle();
                     None
                 }
 
                 // start download
-                (COMPONENT_TREEVIEW, &MSG_KEY_CHAR_S) => {
+                (COMPONENT_TREEVIEW,key) if key==  &MSG_KEY_CHAR_S => {
                     self.mount_youtube_url();
                     None
                 }
 
-                (COMPONENT_TREEVIEW, &MSG_KEY_CHAR_D) => {
+                (COMPONENT_TREEVIEW,key) if key==  &MSG_KEY_CHAR_D => {
                     match self.view.get_state(COMPONENT_TREEVIEW) {
                         Some(Payload::One(Value::Str(node_id))) => {
                             let p: &Path = Path::new(node_id.as_str());
@@ -320,13 +325,13 @@ impl MainActivity {
                 (COMPONENT_INPUT_URL, Msg::OnSubmit(Payload::One(Value::Str(url)))) => {
                         self.umount_youtube_url();
                         if url.starts_with("http") {
-                            self.youtube_dl(&url);
+                            self.youtube_dl(url);
                         } else {
                             self.mount_youtube_options();
                             self.youtube_options_url = url.clone();
                             let domain = self.config.invidious_instance.clone();
                             let mut inv = InvidiousInstance::new(domain);
-                            match inv.get_search_query(&url,1) {
+                            match inv.get_search_query(url,1) {
                                 Ok(y) => {
                                     self.youtube_options = y;
                                     self.youtube_options_index = 1;
@@ -338,7 +343,7 @@ impl MainActivity {
                     None
                 }
 
-                (super::COMPONENT_SCROLLTABLE_YOUTUBE,&MSG_KEY_TAB) => {
+                (super::COMPONENT_SCROLLTABLE_YOUTUBE,key) if key== &MSG_KEY_TAB => {
                     let domain = self.config.invidious_instance.clone();
                     let mut inv = InvidiousInstance::new(domain);
                     self.youtube_options_index +=1;
@@ -352,7 +357,7 @@ impl MainActivity {
                     None
                 }
 
-                (super::COMPONENT_SCROLLTABLE_YOUTUBE,&MSG_KEY_SHIFT_TAB) => {
+                (super::COMPONENT_SCROLLTABLE_YOUTUBE,key) if key== &MSG_KEY_SHIFT_TAB => {
                     let domain = self.config.invidious_instance.clone();
                     let mut inv = InvidiousInstance::new(domain);
                     if self.youtube_options_index >1 {
@@ -367,12 +372,12 @@ impl MainActivity {
                     None
                 }
 
-                (super::COMPONENT_SCROLLTABLE_YOUTUBE,&MSG_KEY_ESC) | (super::COMPONENT_SCROLLTABLE_YOUTUBE,&MSG_KEY_CHAR_CAPITAL_Q)  => {
+                (super::COMPONENT_SCROLLTABLE_YOUTUBE,key) if (key== &MSG_KEY_ESC) | (key == &MSG_KEY_CHAR_CAPITAL_Q)  => {
                     self.umount_youtube_options();
                     None
                 }
 
-                (super::COMPONENT_SCROLLTABLE_YOUTUBE,&MSG_KEY_ENTER) => {
+                (super::COMPONENT_SCROLLTABLE_YOUTUBE,key) if key== &MSG_KEY_ENTER => {
                     if let Some(Payload::One(Value::Usize(index))) = self.view.get_state(super::COMPONENT_SCROLLTABLE_YOUTUBE) {
                         // download from search result here
                         let mut url = "https://www.youtube.com/watch?v=".to_string();
@@ -382,7 +387,7 @@ impl MainActivity {
                     self.umount_youtube_options();
                     None
                 }
-                (COMPONENT_INPUT_URL, &MSG_KEY_ESC) => {
+                (COMPONENT_INPUT_URL,key) if key==  &MSG_KEY_ESC => {
                     self.umount_youtube_url();
                     None
                 }
@@ -401,11 +406,11 @@ impl MainActivity {
                     None
                 }
 
-                (COMPONENT_CONFIRMATION_INPUT, &MSG_KEY_ESC) => {
+                (COMPONENT_CONFIRMATION_INPUT,key) if key==  &MSG_KEY_ESC => {
                     self.umount_confirmation_input();
                     None
                 }
-                (_, &MSG_KEY_CHAR_H) => {
+                (_,key) if key==  &MSG_KEY_CHAR_H => {
                     let event: Event = Event::Key(KeyEvent {
                         code: KeyCode::Left,
                         modifiers: KeyModifiers::NONE,
@@ -413,7 +418,7 @@ impl MainActivity {
                     self.view.on(event);
                     None
                 }
-                (_, &MSG_KEY_CHAR_L) => {
+                (_,key) if key==  &MSG_KEY_CHAR_L => {
                     let event: Event = Event::Key(KeyEvent {
                         code: KeyCode::Right,
                         modifiers: KeyModifiers::NONE,
@@ -438,50 +443,50 @@ impl MainActivity {
                     None
                 }
 
-                (COMPONENT_CONFIRMATION_RADIO, &MSG_KEY_ESC) => {
+                (COMPONENT_CONFIRMATION_RADIO,key) if key==  &MSG_KEY_ESC => {
                     self.umount_confirmation_radio();
                     None
                 }
 
                 // increase volume
-                (_, &MSG_KEY_CHAR_PLUS) | (_, &MSG_KEY_CHAR_EQUAL) => {
+                (_,key) if (key==  &MSG_KEY_CHAR_PLUS) | (key == &MSG_KEY_CHAR_EQUAL) => {
                     self.player.volume_up();
                     None
                 }
                 // decrease volume
-                (_, &MSG_KEY_CHAR_MINUS) | (_, &MSG_KEY_CHAR_DASH) => {
+                (_,key) if (key==  &MSG_KEY_CHAR_MINUS) | (key == &MSG_KEY_CHAR_DASH) => {
                     self.player.volume_down();
                     None
                 }
 
-                (_, &MSG_KEY_QUESTION_MARK) => {
+                (_,key) if key==  &MSG_KEY_QUESTION_MARK => {
                     // Show help
                     self.mount_help();
                     None
                 }
                 // -- help
-                (COMPONENT_TEXT_HELP, &MSG_KEY_ENTER) | (COMPONENT_TEXT_HELP, &MSG_KEY_ESC) => {
+                (COMPONENT_TEXT_HELP,key) if (key==  &MSG_KEY_ENTER) | (key == &MSG_KEY_ESC) => {
                     self.umount_help();
                     None
                 }
                 // -- error
-                (COMPONENT_TEXT_ERROR, &MSG_KEY_ESC) | (COMPONENT_TEXT_ERROR, &MSG_KEY_ENTER) => {
+                (COMPONENT_TEXT_ERROR,key) if (key==  &MSG_KEY_ESC) | (key == &MSG_KEY_ENTER) => {
                     self.umount_error();
                     None
                 }
 
-                (COMPONENT_TREEVIEW, &MSG_KEY_CHAR_T) => {
+                (COMPONENT_TREEVIEW,key) if key==  &MSG_KEY_CHAR_T => {
                     self.run_tageditor();
                     None
                 }
 
                 // Refresh playlist
-                (_, &MSG_KEY_CHAR_R) => {
+                (_,key) if key==  &MSG_KEY_CHAR_R => {
                     self.refresh_playlist();
                     None
                 }
 
-                (_, &MSG_KEY_ESC) | (_, &MSG_KEY_CHAR_CAPITAL_Q) => {
+                (_,key) if (key==  &MSG_KEY_ESC) | (key == &MSG_KEY_CHAR_CAPITAL_Q) => {
                     // Quit on esc
                     self.exit_reason = Some(super::ExitReason::Quit);
                     None
@@ -492,7 +497,10 @@ impl MainActivity {
     }
 
     pub fn update_progress(&mut self) {
-        let (new_prog, time_pos, duration, song_title) = self.player.get_progress();
+        let (new_prog, time_pos, duration) = self.player.get_progress();
+        if (new_prog, time_pos, duration) == (0.9, 0, 100) {
+            return;
+        }
 
         if time_pos >= duration - 1 {
             self.status = Some(Status::Stopped);
@@ -505,20 +513,22 @@ impl MainActivity {
         };
 
         let artist = song.artist().unwrap_or("Unknown Artist");
+        let title = song.title().unwrap_or("Unknown Title");
 
         if time_pos > self.time_pos || time_pos < 2 {
             self.time_pos = time_pos;
             let props = self.view.get_props(COMPONENT_PROGRESS).unwrap();
             let props = progress_bar::ProgressBarPropsBuilder::from(props)
                 .with_progress(new_prog)
-                .with_texts(
-                    Some(format!("Playing: {} - {}", artist, song_title)),
-                    format!(
-                        "{}     :     {} ",
-                        format_duration(Duration::from_secs(time_pos as u64)),
-                        format_duration(Duration::from_secs(duration as u64))
-                    ),
+                .with_title(
+                    format!("Playing: {} - {}", artist, title),
+                    Alignment::Center,
                 )
+                .with_label(format!(
+                    "{}     :     {} ",
+                    format_duration(Duration::from_secs(time_pos as u64)),
+                    format_duration(Duration::from_secs(duration as u64))
+                ))
                 .build();
             self.view.update(COMPONENT_PROGRESS, props);
             self.redraw = true;
@@ -532,10 +542,8 @@ impl MainActivity {
         if song.lyric_frames.is_empty() {
             let props = self.view.get_props(COMPONENT_PARAGRAPH_LYRIC).unwrap();
             let props = paragraph::ParagraphPropsBuilder::from(props)
-                .with_texts(
-                    Some(String::from("Lyrics")),
-                    vec![TextSpanBuilder::new("No lyrics available.").build()],
-                )
+                .with_title("Lyrics", Alignment::Left)
+                .with_texts(vec![TextSpan::new("No lyrics available.")])
                 .build();
             self.view.update(COMPONENT_PARAGRAPH_LYRIC, props);
             return;
@@ -553,10 +561,8 @@ impl MainActivity {
 
         let props = self.view.get_props(COMPONENT_PARAGRAPH_LYRIC).unwrap();
         let props = paragraph::ParagraphPropsBuilder::from(props)
-            .with_texts(
-                Some(String::from("Lyrics")),
-                vec![TextSpanBuilder::new(line.as_ref()).build()],
-            )
+            .with_title("Lyrics", Alignment::Left)
+            .with_texts(vec![TextSpan::new(line)])
             .build();
         self.view.update(COMPONENT_PARAGRAPH_LYRIC, props);
     }
@@ -634,8 +640,8 @@ impl MainActivity {
                     self.view.get_props(super::COMPONENT_LABEL_HELP).unwrap(),
                 )
                 .with_text(text)
-                .with_background(tui::style::Color::Reset)
-                .with_foreground(tui::style::Color::Cyan)
+                .with_background(tuirealm::tui::style::Color::Reset)
+                .with_foreground(tuirealm::tui::style::Color::Cyan)
                 .build();
 
                 let msg = self.view.update(super::COMPONENT_LABEL_HELP, props);
@@ -648,8 +654,8 @@ impl MainActivity {
                     self.view.get_props(super::COMPONENT_LABEL_HELP).unwrap(),
                 )
                 .with_text(text)
-                .with_foreground(tui::style::Color::White)
-                .with_background(tui::style::Color::Red)
+                .with_foreground(tuirealm::tui::style::Color::White)
+                .with_background(tuirealm::tui::style::Color::Red)
                 .build();
 
                 let msg = self.view.update(super::COMPONENT_LABEL_HELP, props);
