@@ -24,23 +24,24 @@
 // Locals
 use super::{
     Context, MainActivity, COMPONENT_LABEL_HELP, COMPONENT_PARAGRAPH_LYRIC, COMPONENT_PROGRESS,
-    COMPONENT_SCROLLTABLE, COMPONENT_TREEVIEW,
+    COMPONENT_TABLE, COMPONENT_TREEVIEW,
 };
 use crate::ui::components::msgbox::{MsgBox, MsgBoxPropsBuilder};
-use crate::ui::components::scrolltable;
+use crate::ui::components::table;
 use crate::ui::draw_area_in;
 // Ext
-use tuirealm::components::{
+use tui_realm_stdlib::{
     input, label, paragraph, progress_bar, radio,
     table::{Table, TablePropsBuilder},
 };
+
 use tuirealm::props::borders::{BorderType, Borders};
-use tuirealm::props::{TableBuilder, TextSpan, TextSpanBuilder};
+use tuirealm::props::{TableBuilder, TextSpan};
 use tuirealm::{PropsBuilder, View};
 // tui
-use tui::layout::{Constraint, Direction, Layout};
-use tui::style::Color;
 use tui_realm_treeview::{TreeView, TreeViewPropsBuilder};
+use tuirealm::tui::layout::{Alignment, Constraint, Direction, Layout};
+use tuirealm::tui::style::Color;
 use tuirealm::tui::widgets::Clear;
 
 impl MainActivity {
@@ -59,7 +60,8 @@ impl MainActivity {
                 progress_bar::ProgressBarPropsBuilder::default()
                     .with_borders(Borders::ALL, BorderType::Rounded, Color::LightMagenta)
                     .with_progbar_color(Color::LightYellow)
-                    .with_texts(Some(String::from("Playing")), String::from("Song Name"))
+                    .with_title("Playing", Alignment::Center)
+                    .with_label("Song Name")
                     .with_background(Color::Black)
                     .with_progress(0.0)
                     .build(),
@@ -80,37 +82,35 @@ impl MainActivity {
                 paragraph::ParagraphPropsBuilder::default()
                     .with_foreground(Color::Cyan)
                     .with_borders(Borders::ALL, BorderType::Rounded, Color::Green)
-                    .with_texts(
-                        Some(String::from("Lyrics")),
-                        vec![
-                            TextSpanBuilder::new("No Lyrics available.")
-                                .underlined()
-                                .with_foreground(Color::Green)
-                                .build(), // ,
-                        ],
-                    )
+                    .with_title("Lyrics", Alignment::Left)
+                    .with_texts(vec![TextSpan::new("No Lyrics available.")
+                        .underlined()
+                        .fg(Color::Green)])
                     .build(),
             )),
         );
 
         // Scrolltable
         self.view.mount(
-            COMPONENT_SCROLLTABLE,
-            Box::new(scrolltable::Scrolltable::new(
-                scrolltable::ScrollTablePropsBuilder::default()
+            COMPONENT_TABLE,
+            Box::new(table::Table::new(
+                table::TablePropsBuilder::default()
                     .with_background(Color::Black)
                     .with_highlighted_str(Some("🚀"))
                     .with_highlighted_color(Color::LightBlue)
                     .with_max_scroll_step(4)
                     .with_borders(Borders::ALL, BorderType::Rounded, Color::Blue)
+                    .scrollable(true)
+                    // .with_title(" Duration ┼─── Artist ───┼────── Title ───────┼────── Album ──────┼────── Queue─")
+                    .with_title("Queue", Alignment::Left)
+                    .with_header(&["Duration", "Artist", "Title", "Album"])
+                    .with_widths(&[10, 20, 25, 45])
                     .with_table(
-                        Some(String::from(
-                            " Duration ┼─── Artist ───┼────── Title ───────┼────── Album ──────┼────── Queue─",
-                        )),
                         TableBuilder::default()
-                            .add_col(TextSpan::from("0"))
-                            .add_col(TextSpan::from(" "))
                             .add_col(TextSpan::from("empty queue"))
+                            .add_col(TextSpan::from(""))
+                            .add_col(TextSpan::from(""))
+                            .add_col(TextSpan::from(""))
                             .build(),
                     )
                     .build(),
@@ -124,7 +124,7 @@ impl MainActivity {
                     .with_borders(Borders::ALL, BorderType::Rounded, Color::LightYellow)
                     .with_foreground(Color::LightYellow)
                     .with_background(Color::Black)
-                    .with_title(Some(String::from("Playlist")))
+                    .with_title("Playlist", Alignment::Left)
                     .with_tree_and_depth(self.tree.root(), 3)
                     .with_highlighted_str("🚀")
                     .build(),
@@ -165,7 +165,7 @@ impl MainActivity {
 
             self.view.render(COMPONENT_TREEVIEW, f, chunks_left[0]);
             self.view.render(COMPONENT_LABEL_HELP, f, chunks_main[1]);
-            self.view.render(COMPONENT_SCROLLTABLE, f, chunks_right[0]);
+            self.view.render(COMPONENT_TABLE, f, chunks_right[0]);
             self.view.render(COMPONENT_PROGRESS, f, chunks_right[1]);
             self.view
                 .render(COMPONENT_PARAGRAPH_LYRIC, f, chunks_right[2]);
@@ -269,10 +269,8 @@ impl MainActivity {
                     .with_color(Color::LightRed)
                     .with_inverted_color(Color::Black)
                     .with_borders(Borders::ALL, BorderType::Rounded, Color::LightRed)
-                    .with_options(
-                        Some(String::from("Delete song?")),
-                        vec![String::from("Yes"), String::from("No")],
-                    )
+                    .with_title("Delete song?", Alignment::Left)
+                    .with_options(&["Yes", "No"])
                     .with_value(1) // Default: No
                     .build(),
             )),
@@ -293,7 +291,7 @@ impl MainActivity {
             super::COMPONENT_CONFIRMATION_INPUT,
             Box::new(input::Input::new(
                 input::InputPropsBuilder::default()
-                    .with_label(String::from("Type DELETE to confirm:"))
+                    .with_label(String::from("Type DELETE to confirm:"), Alignment::Left)
                     .with_borders(Borders::ALL, BorderType::Rounded, Color::Green)
                     .build(),
             )),
@@ -316,7 +314,7 @@ impl MainActivity {
             super::COMPONENT_INPUT_URL,
             Box::new(input::Input::new(
                 input::InputPropsBuilder::default()
-                    .with_label(String::from("Download url or search:"))
+                    .with_label(String::from("Download url or search:"), Alignment::Left)
                     .with_borders(Borders::ALL, BorderType::Rounded, Color::Green)
                     .build(),
             )),
@@ -340,156 +338,59 @@ impl MainActivity {
             Box::new(Table::new(
                 TablePropsBuilder::default()
                     .with_borders(Borders::ALL, BorderType::Rounded, Color::Green)
+                    .with_title("Help", Alignment::Center)
+                    .with_header(&["Key", "Function"])
+                    .with_widths(&[30, 70])
                     .with_table(
-                        Some(String::from("Help")),
                         TableBuilder::default()
-                            .add_col(
-                                TextSpanBuilder::new("<ESC> or <Q>")
-                                    .bold()
-                                    .with_foreground(Color::Cyan)
-                                    .build(),
-                            )
-                            .add_col(TextSpan::from("     Exit"))
+                            .add_col(TextSpan::new("<ESC> or <Q>").bold().fg(Color::Cyan))
+                            .add_col(TextSpan::from("Exit"))
                             .add_row()
-                            .add_col(
-                                TextSpanBuilder::new("<TAB>")
-                                    .bold()
-                                    .with_foreground(Color::Cyan)
-                                    .build(),
-                            )
-                            .add_col(TextSpan::from("            Switch focus"))
+                            .add_col(TextSpan::new("<TAB>").bold().fg(Color::Cyan))
+                            .add_col(TextSpan::from("Switch focus"))
                             .add_row()
-                            .add_col(
-                                TextSpanBuilder::new("<h,j,k,l,g,G>")
-                                    .bold()
-                                    .with_foreground(Color::Cyan)
-                                    .build(),
-                            )
-                            .add_col(TextSpan::from("    Move cursor(vim style)"))
+                            .add_col(TextSpan::new("<h,j,k,l,g,G>").bold().fg(Color::Cyan))
+                            .add_col(TextSpan::from("Move cursor(vim style)"))
                             .add_row()
-                            .add_col(
-                                TextSpanBuilder::new("<f/b>")
-                                    .bold()
-                                    .with_foreground(Color::Cyan)
-                                    .build(),
-                            )
-                            .add_col(TextSpan::from(
-                                "            Seek forward/backward 5 seconds",
-                            ))
+                            .add_col(TextSpan::new("<f/b>").bold().fg(Color::Cyan))
+                            .add_col(TextSpan::from("Seek forward/backward 5 seconds"))
                             .add_row()
-                            .add_col(
-                                TextSpanBuilder::new("<F/B>")
-                                    .bold()
-                                    .with_foreground(Color::Cyan)
-                                    .build(),
-                            )
-                            .add_col(TextSpan::from(
-                                "            Seek forward/backward 1 second for lyrics",
-                            ))
+                            .add_col(TextSpan::new("<F/B>").bold().fg(Color::Cyan))
+                            .add_col(TextSpan::from("Seek forward/backward 1 second for lyrics"))
                             .add_row()
-                            .add_col(
-                                TextSpanBuilder::new("<n/space>")
-                                    .bold()
-                                    .with_foreground(Color::Cyan)
-                                    .build(),
-                            )
-                            .add_col(TextSpan::from("        Next/Pause current song"))
+                            .add_col(TextSpan::new("<n/space>").bold().fg(Color::Cyan))
+                            .add_col(TextSpan::from("Next/Pause current song"))
                             .add_row()
-                            .add_col(
-                                TextSpanBuilder::new("<+,=/-,_>")
-                                    .bold()
-                                    .with_foreground(Color::Cyan)
-                                    .build(),
-                            )
-                            .add_col(TextSpan::from("        Increase/Decrease volume"))
+                            .add_col(TextSpan::new("<+,=/-,_>").bold().fg(Color::Cyan))
+                            .add_col(TextSpan::from("Increase/Decrease volume"))
                             .add_row()
-                            .add_col(
-                                TextSpanBuilder::new(
-                                    "-------------------------Playlist------------------------",
-                                )
-                                .bold()
-                                .with_foreground(Color::LightYellow)
-                                .build(),
-                            )
+                            .add_col(TextSpan::new("Playlist").bold().fg(Color::LightYellow))
                             .add_row()
-                            .add_col(
-                                TextSpanBuilder::new("<l/L>")
-                                    .bold()
-                                    .with_foreground(Color::Cyan)
-                                    .build(),
-                            )
-                            .add_col(TextSpan::from("            Add one/all songs to queue"))
+                            .add_col(TextSpan::new("<l/L>").bold().fg(Color::Cyan))
+                            .add_col(TextSpan::from("Add one/all songs to queue"))
                             .add_row()
-                            .add_col(
-                                TextSpanBuilder::new("<d>")
-                                    .bold()
-                                    .with_foreground(Color::Cyan)
-                                    .build(),
-                            )
-                            .add_col(TextSpan::from("              Delete song or folder"))
+                            .add_col(TextSpan::new("<d>").bold().fg(Color::Cyan))
+                            .add_col(TextSpan::from("Delete song or folder"))
                             .add_row()
-                            .add_col(
-                                TextSpanBuilder::new("<s>")
-                                    .bold()
-                                    .with_foreground(Color::Cyan)
-                                    .build(),
-                            )
-                            .add_col(TextSpan::from(
-                                "              Download or search song from youtube",
-                            ))
+                            .add_col(TextSpan::new("<s>").bold().fg(Color::Cyan))
+                            .add_col(TextSpan::from("Download or search song from youtube"))
                             .add_row()
-                            .add_col(
-                                TextSpanBuilder::new("<t>")
-                                    .bold()
-                                    .with_foreground(Color::Cyan)
-                                    .build(),
-                            )
-                            .add_col(TextSpan::from(
-                                "              Open tag editor for tag and lyric download",
-                            ))
+                            .add_col(TextSpan::new("<t>").bold().fg(Color::Cyan))
+                            .add_col(TextSpan::from("Open tag editor for tag and lyric download"))
                             .add_row()
-                            .add_col(
-                                TextSpanBuilder::new("<y/p>")
-                                    .bold()
-                                    .with_foreground(Color::Cyan)
-                                    .build(),
-                            )
-                            .add_col(TextSpan::from("            Yank and Paste files"))
+                            .add_col(TextSpan::new("<y/p>").bold().fg(Color::Cyan))
+                            .add_col(TextSpan::from("Yank and Paste files"))
                             .add_row()
-                            .add_col(
-                                TextSpanBuilder::new(
-                                    "---------------------------Queue-------------------------",
-                                )
-                                .bold()
-                                .with_foreground(Color::LightYellow)
-                                .build(),
-                            )
+                            .add_col(TextSpan::new("Queue").bold().fg(Color::LightYellow))
                             .add_row()
-                            .add_col(
-                                TextSpanBuilder::new("<d/D>")
-                                    .bold()
-                                    .with_foreground(Color::Cyan)
-                                    .build(),
-                            )
-                            .add_col(TextSpan::from(
-                                "            Delete one/all songs from queue",
-                            ))
+                            .add_col(TextSpan::new("<d/D>").bold().fg(Color::Cyan))
+                            .add_col(TextSpan::from("Delete one/all songs from queue"))
                             .add_row()
-                            .add_col(
-                                TextSpanBuilder::new("<l>")
-                                    .bold()
-                                    .with_foreground(Color::Cyan)
-                                    .build(),
-                            )
-                            .add_col(TextSpan::from("              Play selected"))
+                            .add_col(TextSpan::new("<l>").bold().fg(Color::Cyan))
+                            .add_col(TextSpan::from("Play selected"))
                             .add_row()
-                            .add_col(
-                                TextSpanBuilder::new("<s>")
-                                    .bold()
-                                    .with_foreground(Color::Cyan)
-                                    .build(),
-                            )
-                            .add_col(TextSpan::from("              Shuffle queue"))
+                            .add_col(TextSpan::new("<s>").bold().fg(Color::Cyan))
+                            .add_col(TextSpan::from("Shuffle queue"))
                             .build(),
                     )
                     .build(),
@@ -512,22 +413,20 @@ impl MainActivity {
     pub(super) fn mount_youtube_options(&mut self) {
         self.view.mount(
             super::COMPONENT_SCROLLTABLE_YOUTUBE,
-            Box::new(scrolltable::Scrolltable::new(
-                scrolltable::ScrollTablePropsBuilder::default()
+            Box::new(table::Table::new(
+                table::TablePropsBuilder::default()
                     .with_background(Color::Black)
                     .with_highlighted_str(Some("🚀"))
                     .with_highlighted_color(Color::LightBlue)
                     .with_max_scroll_step(4)
                     .with_borders(Borders::ALL, BorderType::Rounded, Color::Blue)
+                    .with_title("Tab/Shift+Tab for next and previous page", Alignment::Left)
+                    .scrollable(true)
                     .with_table(
-                        Some(String::from(
-                            // " Duration ┼──────── Title ─────────┼────── Album ──────┼────── Queue─",
-                            "Tab/Shift+Tab for next and previous page",
-                        )),
                         TableBuilder::default()
-                            .add_col(TextSpan::from("0"))
-                            .add_col(TextSpan::from(" "))
-                            .add_col(TextSpan::from("empty queue"))
+                            .add_col(TextSpan::from(
+                                "empty queue.Probably the invidious server is down.",
+                            ))
                             .build(),
                     )
                     .build(),
